HXRATE

This package contains modules for hydrogen deuterium exchange (hdx) mass spectrometry data analysis. It contains:

1. backexchange: for backexchange calculations
2. ratefit: for fitting hdx rates
3. openfe: for calculating opening free energy values from hdx rates
4. hxdata: contains methods for reading and writing data
5. methods: contains helper methods

For usage, please refer to the following repository:
https://github.com/sugyandixit/hxrate_pipeline

Under scripts/hxrate/ there are python scripts that uses HXRATE package for rate fitting and opening free energy calculations

You could also use hxrate_pipeline repository for distributed computing in High Performance Computing clusters
(Please refer to README in hxrate_pipeline repository)

Have fun fitting!
